<h1 align="center">
    🐍 lytix-py
</h1>
<p align="center">
This directory contains all the python packages for the Lytix project.
</p>
<p align="center">
    <a href="https://lytix.co">
        <img src="https://img.shields.io/badge/Visit%20Us-Lytix-brightgreen" alt="Lytix">
    </a>  
    <a href="https://badge.fury.io/py/lytix-py">
        <img src="https://badge.fury.io/py/lytix-py.svg" alt="PyPI version">
    </a>
    <a href="https://discord.gg/8TCbHsSe">
        <img src="https://img.shields.io/badge/Join%20our%20community-Discord-blue" alt="Discord Server">
    </a>
</p>


#### Environment Variables

The following environment variables are required to run the Lytix client.

- `LX_API_KEY`: The API key for the Lytix API. This is required to send data to the Lytix API.

The followig environment variables are optional.

- `LX_BASE_URL`: The base URL for the Lytix API. This is required to send data to the Lytix API.
